Skip to contents

An object of class turbineInput containing example turbine dimensions based off a Vestas V90 example. This version has all fixed (i.e. no stochastic) input values and is useful for vignettes and tests

Usage

v90_single

Format

A object of class 'list' and custom class 'turbineInput':

Details

Created with define_turbine()