A non-stochastic example of bird data for vignettes and testing Based off the Australian / Tasmanian Wedge-tailed Eagle
Details
Created with define_bird()
A non-stochastic example of bird data for vignettes and testing Based off the Australian / Tasmanian Wedge-tailed Eagle
Created with define_bird()