An object of class turbineInput containing example turbine dimensions
based off a Vestas V90 example. This version has all fixed (i.e. no stochastic)
input values and is useful for vignettes and tests
Details
Created with define_turbine()
An object of class turbineInput containing example turbine dimensions
based off a Vestas V90 example. This version has all fixed (i.e. no stochastic)
input values and is useful for vignettes and tests
Created with define_turbine()